@@ -8,9 +8,7 @@ __docformat__ = "restructuredtext en"
 
 from logilab.common.deprecation import  deprecated
 
-from cubicweb.mixins import MI_REL_TRIGGERS, TreeMixIn
 from cubicweb.entities import AnyEntity, fetch_config, adapters
-from cubicweb.interfaces import ITree
 from cubicweb.view import EntityAdapter
 from cubicweb.predicates import is_instance
 
@@ -41,7 +39,7 @@ class ClassificationITreeAdapter(EntityAdapter):
 
     def children_rql(self):
         """XXX returns RQL to get children"""
-        return self.entity.related_rql('included_in', 'object')
+        return self.entity.cw_related_rql('included_in', 'object')
 
     def is_leaf(self):
         """returns true if this node as no child"""
@@ -125,16 +123,3 @@ class CodeKeyword(Keyword):
 
     def dc_title(self):
         return u'%s - %s' % (self.code, self.name)
-
-
-class ClassifiableMixIn(object):
-    """mixin automatically plugged to entity types supporting the applied_to
-    relation
-    """
-    def classification_keywords(self, name):
-        """return keywords of the given classification linked to this entity"""
-        return self.req.execute('Any K, KN WHERE K applied_to X, X eid %(x)s, '
-                                'K name KN, K included_in CS, CS name %(name)s',
-                                {'x': self.eid, 'name': name}, 'x')
-
-MI_REL_TRIGGERS[('applied_to', 'object')] = ClassifiableMixIn
