@@ -2,12 +2,12 @@ from logilab.common.testlib import unittest_main
 from cubicweb.devtools.testlib import AutomaticWebTest
 
 class AutomaticWebTest(AutomaticWebTest):
-
+    no_auto_populate = ('Keyword', 'CodeKeyword')
     ignored_relations = set(('descendant_of',))
 
     def to_test_etypes(self):
-        # add cwgroup to test keyword components on entity on which they can be applied
-        return set(('Classification', 'Keyword', 'CWGroup'))
+        # only test the cube related entities
+        return set(('Classification', 'Keyword', 'CodeKeyword'))
 
     def list_startup_views(self):
         return ()
